==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiIssuerFluent<A extends VenafiIssuerFluent<A>> extends BaseFluent<A>{
  public VenafiIssuerFluent() {
  }
  public VenafiIssuerFluent(VenafiIssuer instance) {
    instance = (instance != null ? instance : new VenafiIssuer());

    if (instance != null) {
      this.withCloud(instance.getCloud());
      this.withTpp(instance.getTpp());
      this.withZone(instance.getZone());
      this.withCloud(instance.getCloud());
      this.withTpp(instance.getTpp());
      this.withZone(instance.getZone());
    }
  }
  private VenafiCloudBuilder cloud;
  private VenafiTPPBuilder tpp;
  private String zone;
  public VenafiCloud buildCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  public A withCloud(VenafiCloud cloud) {
    _visitables.get("cloud").remove(this.cloud);
    if (cloud!=null){ this.cloud= new VenafiCloudBuilder(cloud); _visitables.get("cloud").add(this.cloud);} else { this.cloud = null; _visitables.get("cloud").remove(this.cloud); } return (A) this;
  }
  public boolean hasCloud() {
    return this.cloud != null;
  }
  public CloudNested<A> withNewCloud() {
    return new CloudNested(null);
  }
  public CloudNested<A> withNewCloudLike(VenafiCloud item) {
    return new CloudNested(item);
  }
  public CloudNested<A> editCloud() {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(null));
  }
  public CloudNested<A> editOrNewCloud() {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(new VenafiCloudBuilder().build()));
  }
  public CloudNested<A> editOrNewCloudLike(VenafiCloud item) {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(item));
  }
  public VenafiTPP buildTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  public A withTpp(VenafiTPP tpp) {
    _visitables.get("tpp").remove(this.tpp);
    if (tpp!=null){ this.tpp= new VenafiTPPBuilder(tpp); _visitables.get("tpp").add(this.tpp);} else { this.tpp = null; _visitables.get("tpp").remove(this.tpp); } return (A) this;
  }
  public boolean hasTpp() {
    return this.tpp != null;
  }
  public TppNested<A> withNewTpp() {
    return new TppNested(null);
  }
  public TppNested<A> withNewTppLike(VenafiTPP item) {
    return new TppNested(item);
  }
  public TppNested<A> editTpp() {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(null));
  }
  public TppNested<A> editOrNewTpp() {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(new VenafiTPPBuilder().build()));
  }
  public TppNested<A> editOrNewTppLike(VenafiTPP item) {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(item));
  }
  public String getZone() {
    return this.zone;
  }
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  public boolean hasZone() {
    return this.zone != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiIssuerFluent that = (VenafiIssuerFluent) o;
    if (!java.util.Objects.equals(cloud, that.cloud)) return false;

    if (!java.util.Objects.equals(tpp, that.tpp)) return false;

    if (!java.util.Objects.equals(zone, that.zone)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cloud,  tpp,  zone,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cloud != null) { sb.append("cloud:"); sb.append(cloud + ","); }
    if (tpp != null) { sb.append("tpp:"); sb.append(tpp + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone); }
    sb.append("}");
    return sb.toString();
  }
  public class CloudNested<N> extends VenafiCloudFluent<CloudNested<N>> implements Nested<N>{
    CloudNested(VenafiCloud item) {
      this.builder = new VenafiCloudBuilder(this, item);
    }
    VenafiCloudBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluent.this.withCloud(builder.build());
    }
    public N endCloud() {
      return and();
    }
    
  }
  public class TppNested<N> extends VenafiTPPFluent<TppNested<N>> implements Nested<N>{
    TppNested(VenafiTPP item) {
      this.builder = new VenafiTPPBuilder(this, item);
    }
    VenafiTPPBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluent.this.withTpp(builder.build());
    }
    public N endTpp() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class VenafiIssuerFluent<A extends VenafiIssuerFluent<A>> extends BaseFluent<A>{
  public VenafiIssuerFluent() {
  }
  
  public VenafiIssuerFluent(VenafiIssuer instance) {
    this.copyInstance(instance);
  }
  private VenafiCloudBuilder cloud;
  private VenafiTPPBuilder tpp;
  private String zone;
  
  protected void copyInstance(VenafiIssuer instance) {
    instance = (instance != null ? instance : new VenafiIssuer());
  
    if (instance != null) {
        this.withCloud(instance.getCloud());
        this.withTpp(instance.getTpp());
        this.withZone(instance.getZone());
        this.withCloud(instance.getCloud());
        this.withTpp(instance.getTpp());
        this.withZone(instance.getZone());
      }
  }
  
  public VenafiCloud buildCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  
  public A withCloud(VenafiCloud cloud) {
    _visitables.get("cloud").remove(this.cloud);
    if (cloud!=null){ this.cloud= new VenafiCloudBuilder(cloud); _visitables.get("cloud").add(this.cloud);} else { this.cloud = null; _visitables.get("cloud").remove(this.cloud); } return (A) this;
  }
  
  public boolean hasCloud() {
    return this.cloud != null;
  }
  
  public CloudNested<A> withNewCloud() {
    return new CloudNested(null);
  }
  
  public CloudNested<A> withNewCloudLike(VenafiCloud item) {
    return new CloudNested(item);
  }
  
  public CloudNested<A> editCloud() {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(null));
  }
  
  public CloudNested<A> editOrNewCloud() {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(new VenafiCloudBuilder().build()));
  }
  
  public CloudNested<A> editOrNewCloudLike(VenafiCloud item) {
    return withNewCloudLike(java.util.Optional.ofNullable(buildCloud()).orElse(item));
  }
  
  public VenafiTPP buildTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  
  public A withTpp(VenafiTPP tpp) {
    _visitables.get("tpp").remove(this.tpp);
    if (tpp!=null){ this.tpp= new VenafiTPPBuilder(tpp); _visitables.get("tpp").add(this.tpp);} else { this.tpp = null; _visitables.get("tpp").remove(this.tpp); } return (A) this;
  }
  
  public boolean hasTpp() {
    return this.tpp != null;
  }
  
  public TppNested<A> withNewTpp() {
    return new TppNested(null);
  }
  
  public TppNested<A> withNewTppLike(VenafiTPP item) {
    return new TppNested(item);
  }
  
  public TppNested<A> editTpp() {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(null));
  }
  
  public TppNested<A> editOrNewTpp() {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(new VenafiTPPBuilder().build()));
  }
  
  public TppNested<A> editOrNewTppLike(VenafiTPP item) {
    return withNewTppLike(java.util.Optional.ofNullable(buildTpp()).orElse(item));
  }
  
  public String getZone() {
    return this.zone;
  }
  
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  
  public boolean hasZone() {
    return this.zone != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiIssuerFluent that = (VenafiIssuerFluent) o;
    if (!java.util.Objects.equals(cloud, that.cloud)) return false;
  
    if (!java.util.Objects.equals(tpp, that.tpp)) return false;
  
    if (!java.util.Objects.equals(zone, that.zone)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cloud,  tpp,  zone,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cloud != null) { sb.append("cloud:"); sb.append(cloud + ","); }
    if (tpp != null) { sb.append("tpp:"); sb.append(tpp + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone); }
    sb.append("}");
    return sb.toString();
  }
  public class CloudNested<N> extends VenafiCloudFluent<CloudNested<N>> implements Nested<N>{
    CloudNested(VenafiCloud item) {
      this.builder = new VenafiCloudBuilder(this, item);
    }
    VenafiCloudBuilder builder;
    
    public N and() {
      return (N) VenafiIssuerFluent.this.withCloud(builder.build());
    }
    
    public N endCloud() {
      return and();
    }
    
  
  }
  public class TppNested<N> extends VenafiTPPFluent<TppNested<N>> implements Nested<N>{
    TppNested(VenafiTPP item) {
      this.builder = new VenafiTPPBuilder(this, item);
    }
    VenafiTPPBuilder builder;
    
    public N and() {
      return (N) VenafiIssuerFluent.this.withTpp(builder.build());
    }
    
    public N endTpp() {
      return and();
    }
    
  
  }

}
